#
# spec file for package sysextmgr
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           sysextmgr
Version:        0.0+git20250718.e2565a6
Release:        1.1
Summary:        Tools to manage sysext-images on MicroOS
License:        GPL-2.0-or-later
URL:            https://github.com/thkukuk/sysextmgr
Source:         %{name}-%{version}.tar.xz
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libsystemd) >= 257
BuildRequires:  pkgconfig(libeconf)
Requires:       /usr/bin/systemd-dissect
#Requires:       /usr/lib/systemd/systemd-pull
Requires:       systemd-container >= 257.6
Requires:       sysextmgrcli

%description
sysextmgr is used to create and manage json files of dependencies
from systemd-sysext images.

%package -n sysextmgrcli
Summary:        Command line interface for sysextmgr

%description -n sysextmgrcli
sysextmgrcli is a commandline interface to communicate with the sysextmgr daemon via varlink.

%prep
%autosetup

%build
%meson
%meson_build

%install
%meson_install

%check
%meson_test

%pre
%service_add_pre sysextmgr.socket sysextmgr-cleanup.timer

%preun
%service_del_preun sysextmgr.socket sysextmgr-cleanup.timer

%post
%service_add_post sysextmgr.socket sysextmgr-cleanup.timer

%postun
%service_del_postun sysextmgr.socket sysextmgr-cleanup.timer


%files
%license LICENSE.GPL2 LICENSE.LGPL2.1
%{_prefix}/lib/systemd/system/sysextmgr.service
%{_prefix}/lib/systemd/system/sysextmgr.socket
%{_prefix}/lib/systemd/system/sysextmgr-cleanup.service
%{_prefix}/lib/systemd/system/sysextmgr-cleanup.timer
%{_libexecdir}/sysextmgrd

%files -n sysextmgrcli
%license LICENSE.GPL2 LICENSE.LGPL2.1
%{_bindir}/sysextmgrcli

%changelog
* Thu Jul 24 2025 Thorsten Kukuk <kukuk@suse.com>
- File requires for /usr/lib/systemd doesn't work, use
  systemd-container >= 257.6 instead
* Mon Jul 21 2025 Thorsten Kukuk <kukuk@suse.com>
- Update to version 0.0+git20250718.e2565a6:
  * Add timer/service to cleanup sysext images
  * Correct usage of sd_json_variant_is_null()
  * sysextmgrcli: add prefix option for check
  * Create list of installed, but incompatible images
  * extension_release_validate: always use \n for printf
  * sysextmgrcli: fix dispatch table for NULL pointer
  * Implement cleanup in sysextmgrcli
  * sysextmgrd: implement cleanup method
  * Remove debugging comment
  * update cli: add prefix option
  * sysextmgrd: use prefix parameter to read os-relase
  * Add Prefix argument for tukit
  * Add hint about enabling systemd-sysext
* Tue Jul  8 2025 Thorsten Kukuk <kukuk@suse.com>
- Update to version 0.0+git20250708.0d1364c:
  * Use full image name in /etc/extensions
* Tue Jun  3 2025 Thorsten Kukuk <kukuk@suse.com>
- Update to version 0.0+git20250603.3e13bcd:
  * Don't print strerror(-r) if we know r is 0.
  * Only use compatible images for check_for_newer
  * Fix error message output
  * "NewName" can be NULL if no update was found
  * struct osrelease is "const"
  * Fix OS vs. version_id in output
  * Always set "compatibility" if we create an image entry
  * Move osrelease variables in own struct
  * Initial support for ID_LIKE from systemd v258
* Mon May 12 2025 Thorsten Kukuk <kukuk@suse.com>
- Update to version 0.0+git20250512.dddbcd5:
  * Make sure sysext-store directory exists
* Wed Apr 30 2025 Thorsten Kukuk <kukuk@suse.com>
- Update to version 0.0+git20250430.019c9dc:
  * install: make sure etc/extensions directory exists
  * list: ignore if /etc/extensions does not exist
  * Don't block network (systemd-pull)
  * list: don't abort if /var/lib/sysext-store does not exist
  * Enhance and simplify reading of config
  * check: move to varlink
  * Convert "install" to varlink interface
  * update: allow empty new image name for no-update
  * README: document changes for varlink
  * Rename sysext-cli to sysextmgrcli
  * Move "update" to varlink service
  * main-list: free all results
  * Implement sysextmgr daemon via varlink
  * Use strverscmp()
* Wed Apr 23 2025 Thorsten Kukuk <kukuk@suse.com>
- Update to version 0.0+git20250423.2e6c26d:
  * Fix usage of install verb
  * Implement install verb
  * Fix free, fix logic of update entry
  * Implement updating of sysext images
  * Add checks for errors
  * Correctly merge local and remote images
  * Fix list indicies
  * Refactor code to get newest version
  * Use correct function to free deps pointer
  * Enhance free_image_entry*
  * Update usage
  * Implement check for updates verb
  * images-list: add support for /etc/extensions
  * image-deps: add support for images in /etc
  * Differentiate between name of image and full image
  * Remove debug code, fix error message
  * Move image collect data in own function
  * Make url optional, check exec return codes
  * Move struct image_deps and functions to own files
  * Add meson_options.txt
  * Implement "list" verb
  * Update json example
  * Add meson sanitize run
  * Add missing strv.[ch]
  * Add comment from where the code is
  * Fix memory leaks
  * Add list option to display remote images
  * ci-opensuse: install diffutils
  * Adjust github CI workflow
* Thu Apr  3 2025 Thorsten Kukuk <kukuk@suse.com>
- Update to version 0.0+git20250403.c44d956:
  - sysctl-cli with create-json, merge-json and dump-json
* Mon Mar 31 2025 Thorsten Kukuk <kukuk@suse.com>
- Initial version
